Function odra_utils::create_key
source · pub fn create_key(left: &str, right: &str) -> StringExpand description
Joins two parts of a key with the KEY_DELIMITER.
pub fn create_key(left: &str, right: &str) -> StringJoins two parts of a key with the KEY_DELIMITER.